#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-KaLwTedQY7b8GxinbtFykp
key:                  persistent-test-2.13.1.3-KaLwTedQY7b8GxinbtFykp
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  a41f6abca7b0736a6d575f86425fe8a2
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-KaLwTedQY7b8GxinbtFykp
depends:
    HUnit-1.6.2.0-AT4Mx0wk6OXAfe1KUqjGNi
    QuickCheck-2.15.0.1-Ccm6FoEs1pl1n9BgwXAS29
    aeson-2.2.2.0-GDAHVM41MmSECw1rdoDU4M base-4.18.2.1
    blaze-html-0.9.2.0-83CcYrU6EFECuGhqalsaQC bytestring-0.11.5.3
    conduit-1.3.6.1-FOgjaZ5BRlRHF77h52RH4d containers-0.6.7
    exceptions-0.10.7 hspec-2.11.6-JJ2bACdLelc8mPXnW2tl3o
    hspec-expectations-0.8.4-9HP6UZS8rGEGlzbLQDoF6Y
    http-api-data-0.6.1-H6bf2Rx6dpNBEgsbOsD6Yh
    monad-control-1.0.3.1-5erPYSSULl79PGafwvIfx2
    monad-logger-0.3.42-8PNuzv9pEeQIuu2ukAxHyR mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-lkizvJJRNKHBIoX9RSFCf
    quickcheck-instances-0.3.33-3MAvyhFqvARJowzbWPyz5y
    random-1.2.1.3-Cb40hGCJkfVB9pKnqBOmwj
    resourcet-1.2.6-5PamoRo9UJoGlWS0o3Vev5 text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-ENHoQKANHRjoYEIjCCdGS
    unliftio-0.2.25.1-IXXLacMlqlOLLV0xtb4k1H
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-GdjPUvgItW77rL1YhzClz

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

